summaryrefslogtreecommitdiffstats
path: root/knode
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /knode
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'knode')
-rw-r--r--knode/articlewidget.cpp4
-rw-r--r--knode/articlewidget.h2
-rw-r--r--knode/headerview.cpp20
-rw-r--r--knode/headerview.h4
-rw-r--r--knode/knaccountmanager.cpp4
-rw-r--r--knode/knaccountmanager.h2
-rw-r--r--knode/knarticlemanager.cpp14
-rw-r--r--knode/knarticlemanager.h4
-rw-r--r--knode/kncollection.h4
-rw-r--r--knode/kncollectionview.cpp14
-rw-r--r--knode/kncollectionview.h2
-rw-r--r--knode/kncollectionviewitem.cpp6
-rw-r--r--knode/kncollectionviewitem.h4
-rw-r--r--knode/kncomposer.cpp42
-rw-r--r--knode/kncomposer.h10
-rw-r--r--knode/knconfigpages.cpp44
-rw-r--r--knode/knconfigpages.h8
-rw-r--r--knode/knconfigwidgets.cpp4
-rw-r--r--knode/knconfigwidgets.h2
-rw-r--r--knode/knfilterconfigwidget.cpp4
-rw-r--r--knode/knfilterconfigwidget.h2
-rw-r--r--knode/knfilterdialog.cpp4
-rw-r--r--knode/knfilterdialog.h2
-rw-r--r--knode/knfiltermanager.cpp8
-rw-r--r--knode/knfiltermanager.h4
-rw-r--r--knode/knfolder.cpp12
-rw-r--r--knode/knfolder.h6
-rw-r--r--knode/knfoldermanager.cpp12
-rw-r--r--knode/kngroup.cpp4
-rw-r--r--knode/kngroupbrowser.cpp20
-rw-r--r--knode/kngroupbrowser.h4
-rw-r--r--knode/kngroupdialog.cpp4
-rw-r--r--knode/kngroupdialog.h2
-rw-r--r--knode/kngroupmanager.cpp10
-rw-r--r--knode/kngroupmanager.h4
-rw-r--r--knode/kngrouppropdlg.cpp4
-rw-r--r--knode/kngrouppropdlg.h2
-rw-r--r--knode/kngroupselectdialog.cpp4
-rw-r--r--knode/kngroupselectdialog.h2
-rw-r--r--knode/knmainwidget.cpp12
-rw-r--r--knode/knmainwidget.h4
-rw-r--r--knode/knnetaccess.cpp4
-rw-r--r--knode/knnetaccess.h2
-rw-r--r--knode/knnntpaccount.cpp4
-rw-r--r--knode/knnntpaccount.h2
-rw-r--r--knode/knode_part.cpp4
-rw-r--r--knode/knode_part.h2
-rw-r--r--knode/knrangefilter.cpp4
-rw-r--r--knode/knrangefilter.h2
-rw-r--r--knode/knsearchdialog.cpp4
-rw-r--r--knode/knsearchdialog.h2
-rw-r--r--knode/knstatusfilter.cpp6
-rw-r--r--knode/knstatusfilter.h4
-rw-r--r--knode/knstringfilter.cpp4
-rw-r--r--knode/knstringfilter.h2
-rw-r--r--knode/knwidgets.cpp8
-rw-r--r--knode/knwidgets.h4
-rw-r--r--knode/utilities.cpp12
-rw-r--r--knode/utilities.h6
59 files changed, 200 insertions, 200 deletions
diff --git a/knode/articlewidget.cpp b/knode/articlewidget.cpp
index dde18d69..318832fc 100644
--- a/knode/articlewidget.cpp
+++ b/knode/articlewidget.cpp
@@ -75,11 +75,11 @@ using namespace KNode;
TQValueList<ArticleWidget*> ArticleWidget::mInstances;
-ArticleWidget::ArticleWidget( TQWidget *tqparent,
+ArticleWidget::ArticleWidget( TQWidget *parent,
KXMLGUIClient *guiClient,
KActionCollection *actionCollection,
const char *name ) :
- TQWidget( tqparent, name ),
+ TQWidget( parent, name ),
mArticle( 0 ),
mViewer( 0 ),
mCSSHelper( 0 ),
diff --git a/knode/articlewidget.h b/knode/articlewidget.h
index 7333bf5d..2b951ee7 100644
--- a/knode/articlewidget.h
+++ b/knode/articlewidget.h
@@ -57,7 +57,7 @@ class ArticleWidget : public TQWidget, public KNJobConsumer {
public:
/// Construct a new article widget
- ArticleWidget( TQWidget *tqparent,
+ ArticleWidget( TQWidget *parent,
KXMLGUIClient *guiClient,
KActionCollection *actionCollection,
const char *name = 0 );
diff --git a/knode/headerview.cpp b/knode/headerview.cpp
index 3b76b26e..1451844d 100644
--- a/knode/headerview.cpp
+++ b/knode/headerview.cpp
@@ -32,8 +32,8 @@
#include "knmainwidget.h"
-KNHeaderView::KNHeaderView(TQWidget *tqparent, const char *name) :
- KListView(tqparent,name),
+KNHeaderView::KNHeaderView(TQWidget *parent, const char *name) :
+ KListView(parent,name),
mSortCol( -1 ),
mSortAsc( true ),
mSortByThreadChangeDate( false ),
@@ -171,11 +171,11 @@ void KNHeaderView::ensureItemVisibleWithMargin( const TQListViewItem *i )
if ( !i )
return;
- TQListViewItem *tqparent = i->tqparent();
- while ( tqparent ) {
- if ( !tqparent->isOpen() )
- tqparent->setOpen( true );
- tqparent = tqparent->tqparent();
+ TQListViewItem *parent = i->parent();
+ while ( parent ) {
+ if ( !parent->isOpen() )
+ parent->setOpen( true );
+ parent = parent->parent();
}
mDelayedCenter = -1;
@@ -582,9 +582,9 @@ void KNHeaderView::resetCurrentTime()
//BEGIN: KNHeaderViewToolTip ==================================================
-KNHeaderViewToolTip::KNHeaderViewToolTip( KNHeaderView *tqparent ) :
- TQToolTip( tqparent->viewport() ),
- listView( tqparent )
+KNHeaderViewToolTip::KNHeaderViewToolTip( KNHeaderView *parent ) :
+ TQToolTip( parent->viewport() ),
+ listView( parent )
{
}
diff --git a/knode/headerview.h b/knode/headerview.h
index c7d4c9f6..134f1edd 100644
--- a/knode/headerview.h
+++ b/knode/headerview.h
@@ -32,7 +32,7 @@ class KNHeaderView : public KListView {
friend class KNHdrViewItem;
public:
- KNHeaderView( TQWidget *tqparent, const char *name = 0 );
+ KNHeaderView( TQWidget *parent, const char *name = 0 );
~KNHeaderView();
void setActive( TQListViewItem *item );
@@ -108,7 +108,7 @@ class KNHeaderView : public KListView {
class KNHeaderViewToolTip : public TQToolTip {
public:
- KNHeaderViewToolTip( KNHeaderView *tqparent );
+ KNHeaderViewToolTip( KNHeaderView *parent );
protected:
void maybeTip( const TQPoint &p );
diff --git a/knode/knaccountmanager.cpp b/knode/knaccountmanager.cpp
index 01678265..627ff4cd 100644
--- a/knode/knaccountmanager.cpp
+++ b/knode/knaccountmanager.cpp
@@ -34,8 +34,8 @@
KWallet::Wallet* KNAccountManager::mWallet = 0;
bool KNAccountManager::mWalletOpenFailed = false;
-KNAccountManager::KNAccountManager(KNGroupManager *gm, TQObject * tqparent, const char * name)
- : TQObject(tqparent, name), gManager(gm), c_urrentAccount(0),
+KNAccountManager::KNAccountManager(KNGroupManager *gm, TQObject * parent, const char * name)
+ : TQObject(parent, name), gManager(gm), c_urrentAccount(0),
mAsyncOpening( false )
{
s_mtp = new KNServerInfo();
diff --git a/knode/knaccountmanager.h b/knode/knaccountmanager.h
index 53f048b5..4b1227fc 100644
--- a/knode/knaccountmanager.h
+++ b/knode/knaccountmanager.h
@@ -33,7 +33,7 @@ class KNAccountManager : public TQObject
TQ_OBJECT
public:
- KNAccountManager(KNGroupManager *gm, TQObject * tqparent=0, const char * name=0);
+ KNAccountManager(KNGroupManager *gm, TQObject * parent=0, const char * name=0);
~KNAccountManager();
void prepareShutdown();
diff --git a/knode/knarticlemanager.h b/knode/knarticlemanager.h
index 08423cf8..7b052561 100644
--- a/knode/knarticlemanager.h
+++ b/knode/knarticlemanager.h
@@ -47,8 +47,8 @@ class KNArticleManager : public TQObject, public KNJobConsumer {
//content handling
void deleteTempFiles();
- void saveContentToFile(KMime::Content *c, TQWidget *tqparent);
- void saveArticleToFile(KNArticle *a, TQWidget *tqparent);
+ void saveContentToFile(KMime::Content *c, TQWidget *parent);
+ void saveArticleToFile(KNArticle *a, TQWidget *parent);
TQString saveContentToTemp(KMime::Content *c);
void openContent(KMime::Content *c);
diff --git a/knode/kncollection.h b/knode/kncollection.h
index 697021c4..f6c4b915 100644
--- a/knode/kncollection.h
+++ b/knode/kncollection.h
@@ -45,8 +45,8 @@ class KNCollection {
virtual bool readInfo(const TQString &confPath)=0;
virtual void saveInfo()=0;
- // tqparent
- KNCollection* tqparent()const { return p_arent; }
+ // parent
+ KNCollection* parent()const { return p_arent; }
virtual void setParent(KNCollection *p) { p_arent=p; }
// name
diff --git a/knode/kncollectionview.h b/knode/kncollectionview.h
index fe25618f..c48b7f44 100644
--- a/knode/kncollectionview.h
+++ b/knode/kncollectionview.h
@@ -30,7 +30,7 @@ class KNCollectionView : public KFolderTree {
TQ_OBJECT
public:
- KNCollectionView(TQWidget *tqparent, const char *name = 0);
+ KNCollectionView(TQWidget *parent, const char *name = 0);
~KNCollectionView();
void setActive(TQListViewItem *item);
diff --git a/knode/kncollectionviewitem.h b/knode/kncollectionviewitem.h
index 14381a29..4f343147 100644
--- a/knode/kncollectionviewitem.h
+++ b/knode/kncollectionviewitem.h
@@ -28,8 +28,8 @@ class KNCollection;
class KNCollectionViewItem : public KFolderTreeItem {
public:
- KNCollectionViewItem( KFolderTree *tqparent, Protocol protocol = NONE, Type type = Root);
- KNCollectionViewItem( KFolderTreeItem *tqparent, Protocol protocol = NONE,
+ KNCollectionViewItem( KFolderTree *parent, Protocol protocol = NONE, Type type = Root);
+ KNCollectionViewItem( KFolderTreeItem *parent, Protocol protocol = NONE,
Type type = Other, int unread = 0, int total = 0 );
~KNCollectionViewItem();
diff --git a/knode/kncomposer.cpp b/knode/kncomposer.cpp
index 60564d39..af9132d7 100644
--- a/knode/kncomposer.cpp
+++ b/knode/kncomposer.cpp
@@ -63,8 +63,8 @@ using KRecentAddress::RecentAddresses;
#include <kstdguiitem.h>
KNLineEdit::KNLineEdit(KNComposer::ComposerView *_composerView, bool useCompletion,
- TQWidget *tqparent, const char *name)
- : KNLineEditInherited(tqparent,useCompletion,name) , composerView(_composerView)
+ TQWidget *parent, const char *name)
+ : KNLineEditInherited(parent,useCompletion,name) , composerView(_composerView)
{
}
@@ -131,8 +131,8 @@ void KNLineEdit::keyPressEvent(TQKeyEvent *e)
KNLineEditInherited::keyPressEvent(e);
}
-KNLineEditSpell::KNLineEditSpell( KNComposer::ComposerView *_composerView, bool useCompletion,TQWidget * tqparent, const char * name)
- :KNLineEdit( _composerView, useCompletion, tqparent,name )
+KNLineEditSpell::KNLineEditSpell( KNComposer::ComposerView *_composerView, bool useCompletion,TQWidget * parent, const char * name)
+ :KNLineEdit( _composerView, useCompletion, parent,name )
{
}
@@ -1744,7 +1744,7 @@ KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
hdrL->addWidget(l_to, 0,0);
hdrL->addWidget(t_o, 0,1);
hdrL->addWidget(t_oBtn, 0,2);
- connect(t_oBtn, TQT_SIGNAL(clicked()), tqparent(), TQT_SLOT(slotToBtnClicked()));
+ connect(t_oBtn, TQT_SIGNAL(clicked()), parent(), TQT_SLOT(slotToBtnClicked()));
//Newsgroups
g_roups=new KNLineEdit(this, false, hdrFrame);
@@ -1756,8 +1756,8 @@ KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
hdrL->addWidget(g_roups, 1,1);
hdrL->addWidget(g_roupsBtn, 1,2);
connect(g_roups, TQT_SIGNAL(textChanged(const TQString&)),
- tqparent(), TQT_SLOT(slotGroupsChanged(const TQString&)));
- connect(g_roupsBtn, TQT_SIGNAL(clicked()), tqparent(), TQT_SLOT(slotGroupsBtnClicked()));
+ parent(), TQT_SLOT(slotGroupsChanged(const TQString&)));
+ connect(g_roupsBtn, TQT_SIGNAL(clicked()), parent(), TQT_SLOT(slotGroupsBtnClicked()));
//Followup-To
f_up2=new KComboBox(true, hdrFrame);
@@ -1773,7 +1773,7 @@ KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
hdrL->addWidget(l, 3,0);
hdrL->addMultiCellWidget(s_ubject, 3,3, 1,2);
connect(s_ubject, TQT_SIGNAL(textChanged(const TQString&)),
- tqparent(), TQT_SLOT(slotSubjectChanged(const TQString&)));
+ parent(), TQT_SLOT(slotSubjectChanged(const TQString&)));
//Editor
e_dit=new Editor(this, composer, main);
@@ -1907,32 +1907,32 @@ void KNComposer::ComposerView::showAttachmentView()
//connections
connect(a_ttView, TQT_SIGNAL(currentChanged(TQListViewItem*)),
- tqparent(), TQT_SLOT(slotAttachmentSelected(TQListViewItem*)));
+ parent(), TQT_SLOT(slotAttachmentSelected(TQListViewItem*)));
connect(a_ttView, TQT_SIGNAL(clicked ( TQListViewItem * )),
- tqparent(), TQT_SLOT(slotAttachmentSelected(TQListViewItem*)));
+ parent(), TQT_SLOT(slotAttachmentSelected(TQListViewItem*)));
connect(a_ttView, TQT_SIGNAL(contextMenu(KListView*, TQListViewItem*, const TQPoint&)),
- tqparent(), TQT_SLOT(slotAttachmentPopup(KListView*, TQListViewItem*, const TQPoint&)));
+ parent(), TQT_SLOT(slotAttachmentPopup(KListView*, TQListViewItem*, const TQPoint&)));
connect(a_ttView, TQT_SIGNAL(delPressed(TQListViewItem*)),
- tqparent(), TQT_SLOT(slotAttachmentRemove(TQListViewItem*)));
+ parent(), TQT_SLOT(slotAttachmentRemove(TQListViewItem*)));
connect(a_ttView, TQT_SIGNAL(doubleClicked(TQListViewItem*)),
- tqparent(), TQT_SLOT(slotAttachmentEdit(TQListViewItem*)));
+ parent(), TQT_SLOT(slotAttachmentEdit(TQListViewItem*)));
connect(a_ttView, TQT_SIGNAL(returnPressed(TQListViewItem*)),
- tqparent(), TQT_SLOT(slotAttachmentEdit(TQListViewItem*)));
+ parent(), TQT_SLOT(slotAttachmentEdit(TQListViewItem*)));
//buttons
a_ttAddBtn=new TQPushButton(i18n("A&dd..."),a_ttWidget);
- connect(a_ttAddBtn, TQT_SIGNAL(clicked()), tqparent(), TQT_SLOT(slotAttachFile()));
+ connect(a_ttAddBtn, TQT_SIGNAL(clicked()), parent(), TQT_SLOT(slotAttachFile()));
topL->addWidget(a_ttAddBtn, 0,1);
a_ttRemoveBtn=new TQPushButton(i18n("&Remove"), a_ttWidget);
a_ttRemoveBtn->setEnabled(false);
- connect(a_ttRemoveBtn, TQT_SIGNAL(clicked()), tqparent(), TQT_SLOT(slotRemoveAttachment()));
+ connect(a_ttRemoveBtn, TQT_SIGNAL(clicked()), parent(), TQT_SLOT(slotRemoveAttachment()));
topL->addWidget(a_ttRemoveBtn, 1,1);
a_ttEditBtn=new TQPushButton(i18n("&Properties"), a_ttWidget);
a_ttEditBtn->setEnabled(false);
- connect(a_ttEditBtn, TQT_SIGNAL(clicked()), tqparent(), TQT_SLOT(slotAttachmentProperties()));
+ connect(a_ttEditBtn, TQT_SIGNAL(clicked()), parent(), TQT_SLOT(slotAttachmentProperties()));
topL->addWidget(a_ttEditBtn, 2,1, TQt::AlignTop);
topL->setRowStretch(2,1);
@@ -1991,8 +1991,8 @@ void KNComposer::ComposerView::hideExternalNotification()
//=====================================================================================
#include <kcursor.h>
-KNComposer::Editor::Editor(KNComposer::ComposerView *_composerView, KNComposer *_composer, TQWidget *tqparent, char *name)
- : KEdit(tqparent, name), m_composer( _composer ), m_composerView(_composerView)
+KNComposer::Editor::Editor(KNComposer::ComposerView *_composerView, KNComposer *_composer, TQWidget *parent, char *name)
+ : KEdit(parent, name), m_composer( _composer ), m_composerView(_composerView)
{
setOverwriteEnabled(true);
spell = 0L;
@@ -2490,8 +2490,8 @@ void KNComposer::Editor::slotCorrectWord()
//=====================================================================================
-KNComposer::AttachmentView::AttachmentView(TQWidget *tqparent, char *name)
- : KListView(tqparent, name)
+KNComposer::AttachmentView::AttachmentView(TQWidget *parent, char *name)
+ : KListView(parent, name)
{
setFrameStyle(TQFrame::WinPanel | TQFrame::Sunken); // match the TQMultiLineEdit style
addColumn(i18n("File"), 115);
diff --git a/knode/knconfigpages.cpp b/knode/knconfigpages.cpp
index fa0593c2..030838ac 100644
--- a/knode/knconfigpages.cpp
+++ b/knode/knconfigpages.cpp
@@ -28,8 +28,8 @@
//
// common config page with tabs (code mostly taken from kmail)
//
-KNConfig::BasePageWithTabs::BasePageWithTabs( TQWidget * tqparent, const char * name )
- : KCModule( tqparent, name )
+KNConfig::BasePageWithTabs::BasePageWithTabs( TQWidget * parent, const char * name )
+ : KCModule( parent, name )
{
TQVBoxLayout *vlay = new TQVBoxLayout( this, 0, KDialog::spacingHint() );
mTabWidget = new TQTabWidget( this );
@@ -72,11 +72,11 @@ void KNConfig::BasePageWithTabs::defaults() {
//
extern "C"
{
- KDE_EXPORT KCModule *create_knode_config_identity( TQWidget *tqparent, const char * )
+ KDE_EXPORT KCModule *create_knode_config_identity( TQWidget *parent, const char * )
{
KNConfig::IdentityWidget *page = new KNConfig::IdentityWidget(
knGlobals.configManager()->identity(),
- tqparent,
+ parent,
"kcmknode_config_identity" );
return page;
}
@@ -89,15 +89,15 @@ extern "C"
//
extern "C"
{
- KCModule *create_knode_config_accounts( TQWidget *tqparent, const char * )
+ KCModule *create_knode_config_accounts( TQWidget *parent, const char * )
{
- KNConfig::AccountsPage *page = new KNConfig::AccountsPage( tqparent, "kcmknode_config_accounts" );
+ KNConfig::AccountsPage *page = new KNConfig::AccountsPage( parent, "kcmknode_config_accounts" );
return page;
}
}
-KNConfig::AccountsPage::AccountsPage(TQWidget *tqparent, const char *name)
- : BasePageWithTabs(tqparent, name) {
+KNConfig::AccountsPage::AccountsPage(TQWidget *parent, const char *name)
+ : BasePageWithTabs(parent, name) {
addTab(new KNConfig::NntpAccountListWidget(this), i18n("Newsgroup Servers"));
addTab(new KNConfig::SmtpAccountWidget(this), i18n("Mail Server (SMTP)"));
@@ -110,9 +110,9 @@ KNConfig::AccountsPage::AccountsPage(TQWidget *tqparent, const char *name)
//
extern "C"
{
- KCModule *create_knode_config_appearance( TQWidget *tqparent, const char * )
+ KCModule *create_knode_config_appearance( TQWidget *parent, const char * )
{
- KNConfig::AppearanceWidget *page = new KNConfig::AppearanceWidget( tqparent, "kcmknode_config_appearance" );
+ KNConfig::AppearanceWidget *page = new KNConfig::AppearanceWidget( parent, "kcmknode_config_appearance" );
return page;
}
}
@@ -124,15 +124,15 @@ extern "C"
//
extern "C"
{
- KCModule *create_knode_config_read_news( TQWidget *tqparent, const char * )
+ KCModule *create_knode_config_read_news( TQWidget *parent, const char * )
{
- KNConfig::ReadNewsPage *page = new KNConfig::ReadNewsPage( tqparent, "kcmknode_config_read_news" );
+ KNConfig::ReadNewsPage *page = new KNConfig::ReadNewsPage( parent, "kcmknode_config_read_news" );
return page;
}
}
-KNConfig::ReadNewsPage::ReadNewsPage(TQWidget *tqparent, const char *name)
- : BasePageWithTabs(tqparent, name) {
+KNConfig::ReadNewsPage::ReadNewsPage(TQWidget *parent, const char *name)
+ : BasePageWithTabs(parent, name) {
KNConfigManager *cfgMgr = knGlobals.configManager();
addTab(new KNConfig::ReadNewsGeneralWidget(cfgMgr->readNewsGeneral(), this), i18n("General"));
@@ -150,15 +150,15 @@ KNConfig::ReadNewsPage::ReadNewsPage(TQWidget *tqparent, const char *name)
//
extern "C"
{
- KCModule *create_knode_config_post_news( TQWidget *tqparent, const char * )
+ KCModule *create_knode_config_post_news( TQWidget *parent, const char * )
{
- KNConfig::PostNewsPage *page = new KNConfig::PostNewsPage( tqparent, "kcmknode_config_post_news" );
+ KNConfig::PostNewsPage *page = new KNConfig::PostNewsPage( parent, "kcmknode_config_post_news" );
return page;
}
}
-KNConfig::PostNewsPage::PostNewsPage(TQWidget *tqparent, const char *name)
- : BasePageWithTabs(tqparent, name) {
+KNConfig::PostNewsPage::PostNewsPage(TQWidget *parent, const char *name)
+ : BasePageWithTabs(parent, name) {
KNConfigManager *cfgMgr = knGlobals.configManager();
addTab(new KNConfig::PostNewsTechnicalWidget(cfgMgr->postNewsTechnical(), this), i18n("Technical"));
@@ -173,9 +173,9 @@ KNConfig::PostNewsPage::PostNewsPage(TQWidget *tqparent, const char *name)
//
extern "C"
{
- KCModule *create_knode_config_privacy( TQWidget *tqparent, const char * )
+ KCModule *create_knode_config_privacy( TQWidget *parent, const char * )
{
- KNConfig::PrivacyWidget *page = new KNConfig::PrivacyWidget( tqparent, "kcmknode_config_privacy" );
+ KNConfig::PrivacyWidget *page = new KNConfig::PrivacyWidget( parent, "kcmknode_config_privacy" );
return page;
}
}
@@ -187,9 +187,9 @@ extern "C"
//
extern "C"
{
- KCModule *create_knode_config_cleanup( TQWidget *tqparent, const char * )
+ KCModule *create_knode_config_cleanup( TQWidget *parent, const char * )
{
- KNConfig::CleanupWidget *page = new KNConfig::CleanupWidget( tqparent, "kcmknode_config_cleanup" );
+ KNConfig::CleanupWidget *page = new KNConfig::CleanupWidget( parent, "kcmknode_config_cleanup" );
return page;
}
}
diff --git a/knode/knconfigpages.h b/knode/knconfigpages.h
index 3f009c1d..5479d3c8 100644
--- a/knode/knconfigpages.h
+++ b/knode/knconfigpages.h
@@ -33,7 +33,7 @@ class KDE_EXPORT BasePageWithTabs : public KCModule {
Q_OBJECT
TQ_OBJECT
public:
- BasePageWithTabs( TQWidget * tqparent=0, const char * name=0 );
+ BasePageWithTabs( TQWidget * parent=0, const char * name=0 );
~BasePageWithTabs() {};
virtual void load();
@@ -55,7 +55,7 @@ class AccountsPage : public BasePageWithTabs {
TQ_OBJECT
public:
- AccountsPage(TQWidget *tqparent = 0, const char *name = 0);
+ AccountsPage(TQWidget *parent = 0, const char *name = 0);
};
@@ -65,7 +65,7 @@ class KDE_EXPORT ReadNewsPage : public BasePageWithTabs {
TQ_OBJECT
public:
- ReadNewsPage(TQWidget *tqparent = 0, const char *name = 0);
+ ReadNewsPage(TQWidget *parent = 0, const char *name = 0);
};
// post news page
@@ -74,7 +74,7 @@ class KDE_EXPORT PostNewsPage : public BasePageWithTabs {
TQ_OBJECT
public:
- PostNewsPage(TQWidget *tqparent = 0, const char *name = 0);
+ PostNewsPage(TQWidget *parent = 0, const char *name = 0);
};
diff --git a/knode/knconfigwidgets.cpp b/knode/knconfigwidgets.cpp
index a915fe17..0860ee05 100644
--- a/knode/knconfigwidgets.cpp
+++ b/knode/knconfigwidgets.cpp
@@ -2360,8 +2360,8 @@ void KNConfig::PrivacyWidget::save()
//BEGIN: Cleanup configuration widgets ---------------------------------------
-KNConfig::GroupCleanupWidget::GroupCleanupWidget( Cleanup *data, TQWidget *tqparent, const char *name )
- : TQWidget( tqparent, name ), mData( data )
+KNConfig::GroupCleanupWidget::GroupCleanupWidget( Cleanup *data, TQWidget *parent, const char *name )
+ : TQWidget( parent, name ), mData( data )
{
TQVBoxLayout *top = new TQVBoxLayout( this );
diff --git a/knode/knconfigwidgets.h b/knode/knconfigwidgets.h
index 806f6b82..adaec613 100644
--- a/knode/knconfigwidgets.h
+++ b/knode/knconfigwidgets.h
@@ -658,7 +658,7 @@ class KDE_EXPORT GroupCleanupWidget : public TQWidget {
TQ_OBJECT
public:
- GroupCleanupWidget( Cleanup *data, TQWidget *tqparent = 0, const char *name = 0 );
+ GroupCleanupWidget( Cleanup *data, TQWidget *parent = 0, const char *name = 0 );
void load();
void save();
diff --git a/knode/knfilterconfigwidget.cpp b/knode/knfilterconfigwidget.cpp
index f3870c1b..a345e93f 100644
--- a/knode/knfilterconfigwidget.cpp
+++ b/knode/knfilterconfigwidget.cpp
@@ -25,8 +25,8 @@
#include "knfilterconfigwidget.h"
-KNFilterConfigWidget::KNFilterConfigWidget(TQWidget *tqparent, const char *name ) :
- TQTabWidget(tqparent,name)
+KNFilterConfigWidget::KNFilterConfigWidget(TQWidget *parent, const char *name ) :
+ TQTabWidget(parent,name)
{
TQWidget *sf, *idW, *add;
sf=new TQWidget(this);
diff --git a/knode/knfilterconfigwidget.h b/knode/knfilterconfigwidget.h
index 94a100d7..b0903a0c 100644
--- a/knode/knfilterconfigwidget.h
+++ b/knode/knfilterconfigwidget.h
@@ -33,7 +33,7 @@ class KNFilterConfigWidget : public TQTabWidget {
friend class KNSearchDialog;
public:
- KNFilterConfigWidget(TQWidget *tqparent=0, const char *name=0);
+ KNFilterConfigWidget(TQWidget *parent=0, const char *name=0);
~KNFilterConfigWidget();
void reset();
diff --git a/knode/knfilterdialog.cpp b/knode/knfilterdialog.cpp
index 399c0078..ea05a21c 100644
--- a/knode/knfilterdialog.cpp
+++ b/knode/knfilterdialog.cpp
@@ -30,9 +30,9 @@
#include "knfilterdialog.h"
-KNFilterDialog::KNFilterDialog(KNArticleFilter *f, TQWidget *tqparent, const char *name)
+KNFilterDialog::KNFilterDialog(KNArticleFilter *f, TQWidget *parent, const char *name)
: KDialogBase(Plain, (f->id()==-1)? i18n("New Filter"):i18n("Properties of %1").tqarg(f->name()),
- Ok|Cancel|Help, Ok, tqparent, name),
+ Ok|Cancel|Help, Ok, parent, name),
fltr(f)
{
TQFrame* page=plainPage();
diff --git a/knode/knfilterdialog.h b/knode/knfilterdialog.h
index 69e5c45d..875217c9 100644
--- a/knode/knfilterdialog.h
+++ b/knode/knfilterdialog.h
@@ -34,7 +34,7 @@ class KNFilterDialog : public KDialogBase {
friend class KNFilterManager;
public:
- KNFilterDialog(KNArticleFilter *f=0, TQWidget *tqparent=0, const char *name=0);
+ KNFilterDialog(KNArticleFilter *f=0, TQWidget *parent=0, const char *name=0);
~KNFilterDialog();
KNArticleFilter* filter() { return fltr; }
diff --git a/knode/knfiltermanager.cpp b/knode/knfiltermanager.cpp
index 67302063..92fde504 100644
--- a/knode/knfiltermanager.cpp
+++ b/knode/knfiltermanager.cpp
@@ -30,8 +30,8 @@
KNFilterSelectAction::KNFilterSelectAction( const TQString& text, const TQString& pix,
- TQObject* tqparent, const char *name )
- : KActionMenu(text,pix,tqparent,name), currentItem(-42)
+ TQObject* parent, const char *name )
+ : KActionMenu(text,pix,parent,name), currentItem(-42)
{
popupMenu()->setCheckable(true);
connect(popupMenu(),TQT_SIGNAL(activated(int)),this,TQT_SLOT(slotMenuActivated(int)));
@@ -61,8 +61,8 @@ void KNFilterSelectAction::slotMenuActivated(int id)
//==============================================================================
-KNFilterManager::KNFilterManager(TQObject * tqparent, const char * name)
- : TQObject(tqparent,name), fset(0), currFilter(0), a_ctFilter(0)
+KNFilterManager::KNFilterManager(TQObject * parent, const char * name)
+ : TQObject(parent,name), fset(0), currFilter(0), a_ctFilter(0)
{
loadFilters();
diff --git a/knode/knfiltermanager.h b/knode/knfiltermanager.h
index c5c1f974..b037514c 100644
--- a/knode/knfiltermanager.h
+++ b/knode/knfiltermanager.h
@@ -35,7 +35,7 @@ class KNFilterSelectAction : public KActionMenu
public:
KNFilterSelectAction( const TQString& text, const TQString& pix,
- TQObject* tqparent, const char *name );
+ TQObject* parent, const char *name );
~KNFilterSelectAction();
void setCurrentItem(int id);
@@ -57,7 +57,7 @@ class KNFilterManager : public TQObject
TQ_OBJECT
public:
- KNFilterManager(TQObject * tqparent = 0, const char * name = 0);
+ KNFilterManager(TQObject * parent = 0, const char * name = 0);
~KNFilterManager();
void readOptions();
diff --git a/knode/knfolder.cpp b/knode/knfolder.cpp
index 68a43dce..58ac7d0f 100644
--- a/knode/knfolder.cpp
+++ b/knode/knfolder.cpp
@@ -41,8 +41,8 @@ KNFolder::KNFolder()
}
-KNFolder::KNFolder(int id, const TQString &name, KNFolder *tqparent)
- : KNArticleCollection(tqparent), i_d(id), i_ndexDirty(false), w_asOpen(true)
+KNFolder::KNFolder(int id, const TQString &name, KNFolder *parent)
+ : KNArticleCollection(parent), i_d(id), i_ndexDirty(false), w_asOpen(true)
{
TQString fname=path()+TQString("custom_%1").tqarg(i_d);
@@ -51,7 +51,7 @@ KNFolder::KNFolder(int id, const TQString &name, KNFolder *tqparent)
i_ndexFile.setName(fname+".idx");
i_nfoPath=fname+".info";
- p_arentId=tqparent?tqparent->id():-1;
+ p_arentId=parent?parent->id():-1;
if(i_ndexFile.exists())
c_ount=i_ndexFile.size()/sizeof(DynData);
@@ -60,8 +60,8 @@ KNFolder::KNFolder(int id, const TQString &name, KNFolder *tqparent)
}
-KNFolder::KNFolder(int id, const TQString &name, const TQString &prefix, KNFolder *tqparent)
- : KNArticleCollection(tqparent), i_d(id), i_ndexDirty(false), w_asOpen(true)
+KNFolder::KNFolder(int id, const TQString &name, const TQString &prefix, KNFolder *parent)
+ : KNArticleCollection(parent), i_d(id), i_ndexDirty(false), w_asOpen(true)
{
TQString fname=path()+TQString("%1_%2").tqarg(prefix).tqarg(i_d);
@@ -70,7 +70,7 @@ KNFolder::KNFolder(int id, const TQString &name, const TQString &prefix, KNFolde
i_ndexFile.setName(fname+".idx");
i_nfoPath=fname+".info";
- p_arentId=tqparent?tqparent->id():-1;
+ p_arentId=parent?parent->id():-1;
if(i_ndexFile.exists())
c_ount=i_ndexFile.size()/sizeof(DynData);
diff --git a/knode/knfolder.h b/knode/knfolder.h
index 632dbc6e..0be6dafd 100644
--- a/knode/knfolder.h
+++ b/knode/knfolder.h
@@ -28,8 +28,8 @@ class KNFolder : public KNArticleCollection {
public:
KNFolder();
- KNFolder(int id, const TQString &name, KNFolder *tqparent=0);
- KNFolder(int id, const TQString &name, const TQString &prefix, KNFolder *tqparent=0);
+ KNFolder(int id, const TQString &name, KNFolder *parent=0);
+ KNFolder(int id, const TQString &name, const TQString &prefix, KNFolder *parent=0);
~KNFolder();
//type
@@ -58,7 +58,7 @@ class KNFolder : public KNArticleCollection {
KNLocalArticle* byMessageId(const TQCString &mid)
{ return static_cast<KNLocalArticle*>(KNArticleCollection::byMessageId(mid)); }
- //tqparent
+ //parent
void setParent(KNCollection *p);
//load, save and delete
diff --git a/knode/kngroup.cpp b/knode/kngroup.cpp
index a6b3e661..df40915f 100644
--- a/knode/kngroup.cpp
+++ b/knode/kngroup.cpp
@@ -167,8 +167,8 @@ void KNGroup::saveInfo()
KNNntpAccount* KNGroup::account()
{
- KNCollection *p=tqparent();
- while(p->type()!=KNCollection::CTnntpAccount) p=p->tqparent();
+ KNCollection *p=parent();
+ while(p->type()!=KNCollection::CTnntpAccount) p=p->parent();
return (KNNntpAccount*)p_arent;
}
diff --git a/knode/kngroupbrowser.cpp b/knode/kngroupbrowser.cpp
index 584eae40..a3bcb89f 100644
--- a/knode/kngroupbrowser.cpp
+++ b/knode/kngroupbrowser.cpp
@@ -34,9 +34,9 @@
#include <tqpushbutton.h>
-KNGroupBrowser::KNGroupBrowser(TQWidget *tqparent, const TQString &caption, KNNntpAccount *a,
+KNGroupBrowser::KNGroupBrowser(TQWidget *parent, const TQString &caption, KNNntpAccount *a,
int buttons, bool newCBact, const TQString &user1, const TQString &user2) :
- KDialogBase( tqparent, 0L, true, caption, buttons | Help | Ok | Cancel, Ok, true, user1, user2 ),
+ KDialogBase( parent, 0L, true, caption, buttons | Help | Ok | Cancel, Ok, true, user1, user2 ),
incrementalFilter(false), a_ccount(a)
{
refilterTimer = new TQTimer();
@@ -190,7 +190,7 @@ bool KNGroupBrowser::itemInListView(TQListView *view, const KNGroupInfo &gi)
}
-void KNGroupBrowser::createListItems(TQListViewItem *tqparent)
+void KNGroupBrowser::createListItems(TQListViewItem *parent)
{
TQString prefix, tlgn, compare;
TQListViewItem *it;
@@ -198,11 +198,11 @@ void KNGroupBrowser::createListItems(TQListViewItem *tqparent)
int colon;
bool expandit=false;
- if(tqparent) {
- TQListViewItem *p=tqparent;
+ if(parent) {
+ TQListViewItem *p=parent;
while(p) {
prefix.prepend(p->text(0));
- p=p->tqparent();
+ p=p->parent();
}
}
@@ -228,8 +228,8 @@ void KNGroupBrowser::createListItems(TQListViewItem *tqparent)
tlgn = compare.left(colon);
if(expandit) {
- if(tqparent)
- it=new TQListViewItem(tqparent, tlgn);
+ if(parent)
+ it=new TQListViewItem(parent, tlgn);
else
it=new TQListViewItem(groupView, tlgn);
@@ -237,8 +237,8 @@ void KNGroupBrowser::createListItems(TQListViewItem *tqparent)
it->setExpandable(true);
}
else {
- if(tqparent)
- cit=new CheckItem(tqparent, *gn, this);
+ if(parent)
+ cit=new CheckItem(parent, *gn, this);
else
cit=new CheckItem(groupView, *gn, this);
updateItemState(cit);
diff --git a/knode/kngroupbrowser.h b/knode/kngroupbrowser.h
index 4a32d627..65bbb293 100644
--- a/knode/kngroupbrowser.h
+++ b/knode/kngroupbrowser.h
@@ -63,7 +63,7 @@ class KNGroupBrowser : public KDialogBase {
KNGroupInfo info;
};
- KNGroupBrowser(TQWidget *tqparent, const TQString &caption, KNNntpAccount *a, int buttons=0,
+ KNGroupBrowser(TQWidget *parent, const TQString &caption, KNNntpAccount *a, int buttons=0,
bool newCBact=false, const TQString &user1=TQString(), const TQString &user2=TQString());
~KNGroupBrowser();
@@ -81,7 +81,7 @@ class KNGroupBrowser : public KDialogBase {
void changeItemState(const KNGroupInfo &gi, bool s);
bool itemInListView(TQListView *view, const KNGroupInfo &gi);
void removeListItem(TQListView *view, const KNGroupInfo &gi);
- void createListItems(TQListViewItem *tqparent=0);
+ void createListItems(TQListViewItem *parent=0);
TQWidget *page;
TQListView *groupView;
diff --git a/knode/kngroupdialog.cpp b/knode/kngroupdialog.cpp
index 8265be68..0050e96a 100644
--- a/knode/kngroupdialog.cpp
+++ b/knode/kngroupdialog.cpp
@@ -34,8 +34,8 @@
#include <tqpushbutton.h>
-KNGroupDialog::KNGroupDialog(TQWidget *tqparent, KNNntpAccount *a) :
- KNGroupBrowser(tqparent, i18n("Subscribe to Newsgroups"),a, User1 | User2, true, i18n("New &List"), i18n("New &Groups...") )
+KNGroupDialog::KNGroupDialog(TQWidget *parent, KNNntpAccount *a) :
+ KNGroupBrowser(parent, i18n("Subscribe to Newsgroups"),a, User1 | User2, true, i18n("New &List"), i18n("New &Groups...") )
{
rightLabel->setText(i18n("Current changes:"));
subView=new TQListView(page);
diff --git a/knode/kngroupdialog.h b/knode/kngroupdialog.h
index 024e6707..625f2c07 100644
--- a/knode/kngroupdialog.h
+++ b/knode/kngroupdialog.h
@@ -26,7 +26,7 @@ class KNGroupDialog : public KNGroupBrowser {
TQ_OBJECT
public:
- KNGroupDialog(TQWidget *tqparent, KNNntpAccount *a);
+ KNGroupDialog(TQWidget *parent, KNNntpAccount *a);
~KNGroupDialog();
void toSubscribe(TQSortedList<KNGroupInfo> *l);
diff --git a/knode/kngroupmanager.cpp b/knode/kngroupmanager.cpp
index c0677a0a..dd8b0596 100644
--- a/knode/kngroupmanager.cpp
+++ b/knode/kngroupmanager.cpp
@@ -224,8 +224,8 @@ TQSortedList<KNGroupInfo>* KNGroupListData::extractList()
//===============================================================================
-KNGroupManager::KNGroupManager(TQObject * tqparent, const char * name)
- : TQObject(tqparent,name)
+KNGroupManager::KNGroupManager(TQObject * parent, const char * name)
+ : TQObject(parent,name)
{
c_urrentGroup=0;
a_rticleMgr = knGlobals.articleManager();
@@ -393,9 +393,9 @@ void KNGroupManager::expireAll(KNNntpAccount *a)
}
-void KNGroupManager::showGroupDialog(KNNntpAccount *a, TQWidget *tqparent)
+void KNGroupManager::showGroupDialog(KNNntpAccount *a, TQWidget *parent)
{
- KNGroupDialog* gDialog=new KNGroupDialog((tqparent!=0)? tqparent:knGlobals.topWidget, a);
+ KNGroupDialog* gDialog=new KNGroupDialog((parent!=0)? parent:knGlobals.topWidget, a);
connect(gDialog, TQT_SIGNAL(loadList(KNNntpAccount*)), this, TQT_SLOT(slotLoadGroupList(KNNntpAccount*)));
connect(gDialog, TQT_SIGNAL(fetchList(KNNntpAccount*)), this, TQT_SLOT(slotFetchGroupList(KNNntpAccount*)));
@@ -408,7 +408,7 @@ void KNGroupManager::showGroupDialog(KNNntpAccount *a, TQWidget *tqparent)
TQStringList lst;
gDialog->toUnsubscribe(&lst);
if (lst.count()>0) {
- if (KMessageBox::Yes == KMessageBox::questionYesNoList((tqparent!=0)? tqparent:knGlobals.topWidget,i18n("Do you really want to unsubscribe\nfrom these groups?"),
+ if (KMessageBox::Yes == KMessageBox::questionYesNoList((parent!=0)? parent:knGlobals.topWidget,i18n("Do you really want to unsubscribe\nfrom these groups?"),
lst, TQString(), i18n("Unsubscribe"), KStdGuiItem::cancel())) {
for ( TQStringList::Iterator it = lst.begin(); it != lst.end(); ++it ) {
if((g=group(*it, a)))
diff --git a/knode/kngroupmanager.h b/knode/kngroupmanager.h
index 4105e7cd..8b34979d 100644
--- a/knode/kngroupmanager.h
+++ b/knode/kngroupmanager.h
@@ -82,7 +82,7 @@ class KNGroupManager : public TQObject , public KNJobConsumer {
public:
- KNGroupManager(TQObject * tqparent=0, const char * name=0);
+ KNGroupManager(TQObject * parent=0, const char * name=0);
~KNGroupManager();
// group access
@@ -100,7 +100,7 @@ class KNGroupManager : public TQObject , public KNJobConsumer {
void setCurrentGroup(KNGroup *g);
// group handling
- void showGroupDialog(KNNntpAccount *a, TQWidget *tqparent=0);
+ void showGroupDialog(KNNntpAccount *a, TQWidget *parent=0);
void subscribeGroup(const KNGroupInfo *gi, KNNntpAccount *a);
bool unsubscribeGroup(KNGroup *g=0);
void showGroupProperties(KNGroup *g=0);
diff --git a/knode/kngrouppropdlg.cpp b/knode/kngrouppropdlg.cpp
index d5cd7175..264a9444 100644
--- a/knode/kngrouppropdlg.cpp
+++ b/knode/kngrouppropdlg.cpp
@@ -29,9 +29,9 @@
#include <tqlabel.h>
-KNGroupPropDlg::KNGroupPropDlg(KNGroup *group, TQWidget *tqparent, const char *name )
+KNGroupPropDlg::KNGroupPropDlg(KNGroup *group, TQWidget *parent, const char *name )
: KDialogBase(Tabbed, i18n("Properties of %1").tqarg(group->groupname()),
- Ok|Cancel|Help, Ok, tqparent, name),
+ Ok|Cancel|Help, Ok, parent, name),
g_rp(group), n_ickChanged(false)
{
diff --git a/knode/kngrouppropdlg.h b/knode/kngrouppropdlg.h
index eb087dd4..0c640bea 100644
--- a/knode/kngrouppropdlg.h
+++ b/knode/kngrouppropdlg.h
@@ -35,7 +35,7 @@ namespace KNConfig {
class KNGroupPropDlg : public KDialogBase {
public:
- KNGroupPropDlg(KNGroup *group, TQWidget *tqparent=0, const char *name=0);
+ KNGroupPropDlg(KNGroup *group, TQWidget *parent=0, const char *name=0);
~KNGroupPropDlg();
bool nickHasChanged()const { return n_ickChanged; }
diff --git a/knode/kngroupselectdialog.cpp b/knode/kngroupselectdialog.cpp
index bfd37406..6767d3f6 100644
--- a/knode/kngroupselectdialog.cpp
+++ b/knode/kngroupselectdialog.cpp
@@ -27,8 +27,8 @@
#include <tqpushbutton.h>
-KNGroupSelectDialog::KNGroupSelectDialog(TQWidget *tqparent, KNNntpAccount *a, const TQString &act) :
- KNGroupBrowser(tqparent, i18n("Select Destinations"), a)
+KNGroupSelectDialog::KNGroupSelectDialog(TQWidget *parent, KNNntpAccount *a, const TQString &act) :
+ KNGroupBrowser(parent, i18n("Select Destinations"), a)
{
selView=new TQListView(page);
selView->addColumn(TQString());
diff --git a/knode/kngroupselectdialog.h b/knode/kngroupselectdialog.h
index 05b21970..a2d9e016 100644
--- a/knode/kngroupselectdialog.h
+++ b/knode/kngroupselectdialog.h
@@ -26,7 +26,7 @@ class KNGroupSelectDialog : public KNGroupBrowser {
TQ_OBJECT
public:
- KNGroupSelectDialog(TQWidget *tqparent, KNNntpAccount *a, const TQString &act);
+ KNGroupSelectDialog(TQWidget *parent, KNNntpAccount *a, const TQString &act);
~KNGroupSelectDialog();
TQString selectedGroups()const;
diff --git a/knode/knmainwidget.cpp b/knode/knmainwidget.cpp
index 2214cb83..4294f7a5 100644
--- a/knode/knmainwidget.cpp
+++ b/knode/knmainwidget.cpp
@@ -70,9 +70,9 @@ using namespace KNode;
KNGlobals knGlobals;
-KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* tqparent,
+KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* parent,
const char* name )
- : DCOPObject("KNodeIface"), KDockArea( tqparent, name ),
+ : DCOPObject("KNodeIface"), KDockArea( parent, name ),
b_lockui( false ), m_GUIClient( client )
{
knGlobals.top=this;
@@ -983,8 +983,8 @@ void KNMainWidget::closeCurrentThread()
{
TQListViewItem *item = h_drView->currentItem();
if (item) {
- while (item->tqparent())
- item = item->tqparent();
+ while (item->parent())
+ item = item->parent();
h_drView->setCurrentItem(item);
item->setOpen(false);
h_drView->ensureItemVisible(item);
@@ -2043,8 +2043,8 @@ KXMLGUIFactory* KNMainWidget::factory() const
//--------------------------------
-FetchArticleIdDlg::FetchArticleIdDlg(TQWidget *tqparent, const char */*name*/ )
- :KDialogBase(tqparent, 0, true, i18n("Fetch Article with ID"), KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok)
+FetchArticleIdDlg::FetchArticleIdDlg(TQWidget *parent, const char */*name*/ )
+ :KDialogBase(parent, 0, true, i18n("Fetch Article with ID"), KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok)
{
TQHBox *page = makeHBoxMainWidget();
diff --git a/knode/knmainwidget.h b/knode/knmainwidget.h
index 1ddba490..b4189490 100644
--- a/knode/knmainwidget.h
+++ b/knode/knmainwidget.h
@@ -65,7 +65,7 @@ class KDE_EXPORT KNMainWidget : public KDockArea, virtual public KNodeIface
Q_OBJECT
TQ_OBJECT
public:
- KNMainWidget( KXMLGUIClient *client, bool detachable, TQWidget* tqparent, const char* name );
+ KNMainWidget( KXMLGUIClient *client, bool detachable, TQWidget* parent, const char* name );
~KNMainWidget();
/** exit */
@@ -416,7 +416,7 @@ class FetchArticleIdDlg : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- FetchArticleIdDlg(TQWidget *tqparent, const char */*name*/ );
+ FetchArticleIdDlg(TQWidget *parent, const char */*name*/ );
TQString messageId() const;
protected slots:
diff --git a/knode/knnetaccess.cpp b/knode/knnetaccess.cpp
index bb32c04f..ec2c8663 100644
--- a/knode/knnetaccess.cpp
+++ b/knode/knnetaccess.cpp
@@ -37,8 +37,8 @@
using KPIM::ProgressManager;
-KNNetAccess::KNNetAccess(TQObject *tqparent, const char *name )
- : TQObject(tqparent,name), currentNntpJob(0), currentSmtpJob(0)
+KNNetAccess::KNNetAccess(TQObject *parent, const char *name )
+ : TQObject(parent,name), currentNntpJob(0), currentSmtpJob(0)
{
if ( pipe(nntpInPipe) == -1 || pipe(nntpOutPipe) == -1 ) {
KMessageBox::error(knGlobals.topWidget, i18n("Internal error:\nFailed to open pipes for internal communication."));
diff --git a/knode/knnetaccess.h b/knode/knnetaccess.h
index e7ad1fb7..6b34937a 100644
--- a/knode/knnetaccess.h
+++ b/knode/knnetaccess.h
@@ -41,7 +41,7 @@ class KNNetAccess : public TQObject {
public:
- KNNetAccess(TQObject *tqparent=0, const char *name=0);
+ KNNetAccess(TQObject *parent=0, const char *name=0);
~KNNetAccess();
void addJob(KNJobData *job);
diff --git a/knode/knnntpaccount.cpp b/knode/knnntpaccount.cpp
index 1795cbc5..81b3cc42 100644
--- a/knode/knnntpaccount.cpp
+++ b/knode/knnntpaccount.cpp
@@ -181,10 +181,10 @@ TQString KNNntpAccount::path()
}
-bool KNNntpAccount::editProperties(TQWidget *tqparent)
+bool KNNntpAccount::editProperties(TQWidget *parent)
{
if(!i_dentity) i_dentity=new KNConfig::Identity(false);
- KNConfig::NntpAccountConfDialog *d = new KNConfig::NntpAccountConfDialog(this, tqparent);
+ KNConfig::NntpAccountConfDialog *d = new KNConfig::NntpAccountConfDialog(this, parent);
bool ret=false;
if (d->exec()) {
diff --git a/knode/knnntpaccount.h b/knode/knnntpaccount.h
index a84d7a28..3625906f 100644
--- a/knode/knnntpaccount.h
+++ b/knode/knnntpaccount.h
@@ -66,7 +66,7 @@ class KNNntpAccount : public KNCollection , public KNServerInfo {
//void syncInfo();
TQString path();
/** returns true when the user accepted */
- bool editProperties(TQWidget *tqparent);
+ bool editProperties(TQWidget *parent);
// news interval checking
void startTimer();
diff --git a/knode/knode_part.cpp b/knode/knode_part.cpp
index 1f95335e..825de90c 100644
--- a/knode/knode_part.cpp
+++ b/knode/knode_part.cpp
@@ -48,8 +48,8 @@ typedef KParts::GenericFactory< KNodePart > KNodeFactory;
K_EXPORT_COMPONENT_FACTORY( libknodepart, KNodeFactory )
KNodePart::KNodePart(TQWidget *parentWidget, const char *widgetName,
- TQObject *tqparent, const char *name, const TQStringList &)
- : KParts::ReadOnlyPart(tqparent, name),
+ TQObject *parent, const char *name, const TQStringList &)
+ : KParts::ReadOnlyPart(parent, name),
mParentWidget( parentWidget )
{
kdDebug(5003) << "KNodePart()" << endl;
diff --git a/knode/knode_part.h b/knode/knode_part.h
index e8883cb6..b0ed4afa 100644
--- a/knode/knode_part.h
+++ b/knode/knode_part.h
@@ -45,7 +45,7 @@ class KNodePart: public KParts::ReadOnlyPart
TQ_OBJECT
public:
KNodePart(TQWidget *parentWidget, const char *widgetName,
- TQObject *tqparent, const char *name, const TQStringList &);
+ TQObject *parent, const char *name, const TQStringList &);
virtual ~KNodePart();
TQWidget* parentWidget() const;
diff --git a/knode/knrangefilter.cpp b/knode/knrangefilter.cpp
index 23b5753e..28c67b03 100644
--- a/knode/knrangefilter.cpp
+++ b/knode/knrangefilter.cpp
@@ -96,8 +96,8 @@ void KNRangeFilter::save(KSimpleConfig *conf)
//=====================================================================================
//=====================================================================================
-KNRangeFilterWidget::KNRangeFilterWidget(const TQString& value, int min, int max, TQWidget* tqparent, const TQString &unit)
- : TQGroupBox(value, tqparent)
+KNRangeFilterWidget::KNRangeFilterWidget(const TQString& value, int min, int max, TQWidget* parent, const TQString &unit)
+ : TQGroupBox(value, parent)
{
enabled=new TQCheckBox(this);
diff --git a/knode/knrangefilter.h b/knode/knrangefilter.h
index 5c05d4e7..8bf7d950 100644
--- a/knode/knrangefilter.h
+++ b/knode/knrangefilter.h
@@ -66,7 +66,7 @@ class KNRangeFilterWidget : public TQGroupBox {
TQ_OBJECT
public:
- KNRangeFilterWidget(const TQString& value, int min, int max, TQWidget* tqparent, const TQString &unit=TQString());
+ KNRangeFilterWidget(const TQString& value, int min, int max, TQWidget* parent, const TQString &unit=TQString());
~KNRangeFilterWidget();
KNRangeFilter filter();
diff --git a/knode/knsearchdialog.cpp b/knode/knsearchdialog.cpp
index 72e98dd1..4344cbba 100644
--- a/knode/knsearchdialog.cpp
+++ b/knode/knsearchdialog.cpp
@@ -29,8 +29,8 @@
#include "knsearchdialog.h"
-KNSearchDialog::KNSearchDialog(searchType /*t*/, TQWidget *tqparent)
- : TQDialog(tqparent)
+KNSearchDialog::KNSearchDialog(searchType /*t*/, TQWidget *parent)
+ : TQDialog(parent)
{
setCaption(kapp->makeStdCaption( i18n("Search for Articles") ));
setIcon(SmallIcon("knode"));
diff --git a/knode/knsearchdialog.h b/knode/knsearchdialog.h
index 784a855e..f3c0647d 100644
--- a/knode/knsearchdialog.h
+++ b/knode/knsearchdialog.h
@@ -32,7 +32,7 @@ class KNSearchDialog : public TQDialog {
public:
enum searchType { STfolderSearch, STgroupSearch };
- KNSearchDialog(searchType t=STgroupSearch, TQWidget *tqparent=0);
+ KNSearchDialog(searchType t=STgroupSearch, TQWidget *parent=0);
~KNSearchDialog();
KNArticleFilter* filter() const { return f_ilter; }
diff --git a/knode/knstatusfilter.cpp b/knode/knstatusfilter.cpp
index aa92dca5..a1379a26 100644
--- a/knode/knstatusfilter.cpp
+++ b/knode/knstatusfilter.cpp
@@ -94,8 +94,8 @@ bool KNStatusFilter::doFilter(KNRemoteArticle *a)
//==============================================================================
-KNStatusFilterWidget::KNStatusFilterWidget(TQWidget *tqparent) :
- TQButtonGroup(0, tqparent)
+KNStatusFilterWidget::KNStatusFilterWidget(TQWidget *parent) :
+ TQButtonGroup(0, parent)
{
setFrameStyle(NoFrame);
enR=new TQCheckBox(i18n("Is read:"), this);
@@ -197,7 +197,7 @@ void KNStatusFilterWidget::slotEnabled(int c)
//==============================================================================
-KNStatusFilterWidget::TFCombo::TFCombo(TQWidget *tqparent) : TQComboBox(tqparent)
+KNStatusFilterWidget::TFCombo::TFCombo(TQWidget *parent) : TQComboBox(parent)
{
insertItem(i18n("True"));
insertItem(i18n("False"));
diff --git a/knode/knstatusfilter.h b/knode/knstatusfilter.h
index f4ec92cd..109e0455 100644
--- a/knode/knstatusfilter.h
+++ b/knode/knstatusfilter.h
@@ -57,7 +57,7 @@ class KNStatusFilterWidget : public TQButtonGroup {
TQ_OBJECT
public:
- KNStatusFilterWidget(TQWidget *tqparent);
+ KNStatusFilterWidget(TQWidget *parent);
~KNStatusFilterWidget();
KNStatusFilter filter();
@@ -70,7 +70,7 @@ class KNStatusFilterWidget : public TQButtonGroup {
class TFCombo : public TQComboBox {
public:
- TFCombo(TQWidget *tqparent);
+ TFCombo(TQWidget *parent);
~TFCombo();
void setValue(bool b) { if(b) setCurrentItem(0); else setCurrentItem(1); }
bool value() const { return (currentItem()==0); }
diff --git a/knode/knstringfilter.cpp b/knode/knstringfilter.cpp
index 51fdc1bd..4f69f7ea 100644
--- a/knode/knstringfilter.cpp
+++ b/knode/knstringfilter.cpp
@@ -94,8 +94,8 @@ void KNStringFilter::save(KSimpleConfig *conf)
//===============================================================================
-KNStringFilterWidget::KNStringFilterWidget(const TQString& title, TQWidget *tqparent)
- : TQGroupBox(title, tqparent)
+KNStringFilterWidget::KNStringFilterWidget(const TQString& title, TQWidget *parent)
+ : TQGroupBox(title, parent)
{
fType=new TQComboBox(this);
fType->insertItem(i18n("Does Contain"));
diff --git a/knode/knstringfilter.h b/knode/knstringfilter.h
index 44647641..2c93a70d 100644
--- a/knode/knstringfilter.h
+++ b/knode/knstringfilter.h
@@ -61,7 +61,7 @@ class KNStringFilterWidget : public TQGroupBox {
TQ_OBJECT
public:
- KNStringFilterWidget(const TQString& title, TQWidget *tqparent);
+ KNStringFilterWidget(const TQString& title, TQWidget *parent);
~KNStringFilterWidget();
KNStringFilter filter();
diff --git a/knode/knwidgets.cpp b/knode/knwidgets.cpp
index 53feed61..c3f21959 100644
--- a/knode/knwidgets.cpp
+++ b/knode/knwidgets.cpp
@@ -84,8 +84,8 @@ int KNListBoxItem::width(const TQListBox *lb) const
// **** listbox for dialogs **************************************************
-KNDialogListBox::KNDialogListBox(bool alwaysIgnore, TQWidget * tqparent, const char * name)
- : TQListBox(tqparent, name), a_lwaysIgnore(alwaysIgnore)
+KNDialogListBox::KNDialogListBox(bool alwaysIgnore, TQWidget * parent, const char * name)
+ : TQListBox(parent, name), a_lwaysIgnore(alwaysIgnore)
{
}
@@ -107,8 +107,8 @@ void KNDialogListBox::keyPressEvent(TQKeyEvent *e)
//====================================================================================
-KNDockWidgetHeaderDrag::KNDockWidgetHeaderDrag(TQWidget *tqfocusWidget, KDockWidgetAbstractHeader* tqparent, KDockWidget* dock, const char* name )
- : KDockWidgetHeaderDrag(tqparent, dock, name), f_ocus(false)
+KNDockWidgetHeaderDrag::KNDockWidgetHeaderDrag(TQWidget *tqfocusWidget, KDockWidgetAbstractHeader* parent, KDockWidget* dock, const char* name )
+ : KDockWidgetHeaderDrag(parent, dock, name), f_ocus(false)
{
connect(tqfocusWidget, TQT_SIGNAL(focusChanged(TQFocusEvent*)), TQT_SLOT(slotFocusChanged(TQFocusEvent*)));
}
diff --git a/knode/knwidgets.h b/knode/knwidgets.h
index ce13cb8d..002e3137 100644
--- a/knode/knwidgets.h
+++ b/knode/knwidgets.h
@@ -53,7 +53,7 @@ class KNDialogListBox : public TQListBox
{
public:
// alwaysIgnore==false: enter is ignored when the widget isn't visible/out of focus
- KNDialogListBox(bool alwaysIgnore=false, TQWidget * tqparent=0, const char * name=0);
+ KNDialogListBox(bool alwaysIgnore=false, TQWidget * parent=0, const char * name=0);
~KNDialogListBox();
protected:
@@ -72,7 +72,7 @@ class KNDockWidgetHeaderDrag : public KDockWidgetHeaderDrag
TQ_OBJECT
public:
- KNDockWidgetHeaderDrag(TQWidget *tqfocusWidget, KDockWidgetAbstractHeader* tqparent, KDockWidget* dock,
+ KNDockWidgetHeaderDrag(TQWidget *tqfocusWidget, KDockWidgetAbstractHeader* parent, KDockWidget* dock,
const char* name = 0);
virtual ~KNDockWidgetHeaderDrag();
diff --git a/knode/utilities.cpp b/knode/utilities.cpp
index 0927c917..2297387b 100644
--- a/knode/utilities.cpp
+++ b/knode/utilities.cpp
@@ -134,8 +134,8 @@ bool KNFile::increaseBuffer()
TQString KNSaveHelper::lastPath;
-KNSaveHelper::KNSaveHelper(TQString saveName, TQWidget *tqparent)
- : p_arent(tqparent), s_aveName(saveName), file(0), tmpFile(0)
+KNSaveHelper::KNSaveHelper(TQString saveName, TQWidget *parent)
+ : p_arent(parent), s_aveName(saveName), file(0), tmpFile(0)
{
}
@@ -196,8 +196,8 @@ TQFile* KNSaveHelper::getFile(const TQString &dialogTitle)
TQString KNLoadHelper::l_astPath;
-KNLoadHelper::KNLoadHelper(TQWidget *tqparent)
- : p_arent(tqparent), f_ile(0)
+KNLoadHelper::KNLoadHelper(TQWidget *parent)
+ : p_arent(parent), f_ile(0)
{
}
@@ -261,10 +261,10 @@ KNFile* KNLoadHelper::setURL(KURL url)
// **** keyboard selection dialog *********************************************
-int KNHelper::selectDialog(TQWidget *tqparent, const TQString &caption, const TQStringList &options, int initialValue)
+int KNHelper::selectDialog(TQWidget *parent, const TQString &caption, const TQStringList &options, int initialValue)
{
KDialogBase *dlg=new KDialogBase(KDialogBase::Plain, caption, KDialogBase::Ok|KDialogBase::Cancel,
- KDialogBase::Ok, tqparent);
+ KDialogBase::Ok, parent);
TQFrame *page = dlg->plainPage();
TQHBoxLayout *pageL = new TQHBoxLayout(page,8,5);
diff --git a/knode/utilities.h b/knode/utilities.h
index 936665a9..e88ca695 100644
--- a/knode/utilities.h
+++ b/knode/utilities.h
@@ -82,7 +82,7 @@ class KNSaveHelper {
public:
- KNSaveHelper(TQString saveName, TQWidget *tqparent);
+ KNSaveHelper(TQString saveName, TQWidget *parent);
~KNSaveHelper();
/** returns a file open for writing */
@@ -107,7 +107,7 @@ class KNLoadHelper {
public:
- KNLoadHelper(TQWidget *tqparent);
+ KNLoadHelper(TQWidget *parent);
~KNLoadHelper();
/** opens a file dialog and returns a file open for reading */
@@ -140,7 +140,7 @@ public:
/** list selection dialog, used instead of a popup menu
when a select action is called via the keyboard.
returns -1 when the user canceled the dialog. */
- static int selectDialog(TQWidget *tqparent, const TQString &caption, const TQStringList &options, int initialValue);
+ static int selectDialog(TQWidget *parent, const TQString &caption, const TQStringList &options, int initialValue);
static void saveWindowSize(const TQString &name, const TQSize &s);
static void restoreWindowSize(const TQString &name, TQWidget *d, const TQSize &defaultSize);
diff --git a/knode/knarticlemanager.cpp b/knode/knarticlemanager.cpp
index e871b1f5..ab9c97ea 100644
--- a/knode/knarticlemanager.cpp
+++ b/knode/knarticlemanager.cpp
@@ -74,21 +74,21 @@ void KNArticleManager::deleteTempFiles()
}
-void KNArticleManager::saveContentToFile(KMime::Content *c, TQWidget *tqparent)
+void KNArticleManager::saveContentToFile(KMime::Content *c, TQWidget *parent)
{
- KNSaveHelper helper(c->contentType()->name(),tqparent);
+ KNSaveHelper helper(c->contentType()->name(),parent);
TQFile *file = helper.getFile(i18n("Save Attachment"));
if (file) {
TQByteArray data=c->decodedContent();
if (file->writeBlock(data.data(), data.size()) == -1 )
- KNHelper::displayExternalFileError( tqparent );
+ KNHelper::displayExternalFileError( parent );
}
}
-void KNArticleManager::saveArticleToFile(KNArticle *a, TQWidget *tqparent)
+void KNArticleManager::saveArticleToFile(KNArticle *a, TQWidget *parent)
{
TQString fName = a->subject()->asUnicodeString();
TQString s = "";
@@ -101,13 +101,13 @@ void KNArticleManager::saveArticleToFile(KNArticle *a, TQWidget *tqparent)
fName = s.simplifyWhiteSpace();
fName.replace(TQRegExp("[\\s]"),"_");
- KNSaveHelper helper(fName,tqparent);
+ KNSaveHelper helper(fName,parent);
TQFile *file = helper.getFile(i18n("Save Article"));
if (file) {
TQCString tmp=a->encodedContent(false);
if ( file->writeBlock(tmp.data(), tmp.size()) == -1 )
- KNHelper::displayExternalFileError( tqparent );
+ KNHelper::displayExternalFileError( parent );
}
}
@@ -272,7 +272,7 @@ void KNArticleManager::showHdrs(bool clear)
}
- if (current && !current->filterResult()) { // try to find a tqparent that is visible
+ if (current && !current->filterResult()) { // try to find a parent that is visible
int idRef;
while (current && !current->filterResult()) {
idRef=current->idRef();
diff --git a/knode/kncollectionview.cpp b/knode/kncollectionview.cpp
index 1026e642..7b73cc7b 100644
--- a/knode/kncollectionview.cpp
+++ b/knode/kncollectionview.cpp
@@ -32,8 +32,8 @@
#include "kncollectionview.h"
#include "kncollectionviewitem.h"
-KNCollectionView::KNCollectionView(TQWidget *tqparent, const char* name) :
- KFolderTree(tqparent, name),
+KNCollectionView::KNCollectionView(TQWidget *parent, const char* name) :
+ KFolderTree(parent, name),
mActiveItem( 0 ),
mPopup( 0 )
{
@@ -221,13 +221,13 @@ void KNCollectionView::addFolder(KNFolder *f)
{
KNCollectionViewItem *it;
- if (!f->tqparent()) {
+ if (!f->parent()) {
// root folder
it = new KNCollectionViewItem(this, KFolderTreeItem::Local);
} else {
- // make sure the tqparent folder has already been added
- if (!f->tqparent()->listItem())
- addFolder( static_cast<KNFolder*>(f->tqparent()) );
+ // make sure the parent folder has already been added
+ if (!f->parent()->listItem())
+ addFolder( static_cast<KNFolder*>(f->parent()) );
// handle special folders
KFolderTreeItem::Type type = KFolderTreeItem::Other;
switch ( f->id() ) {
@@ -238,7 +238,7 @@ void KNCollectionView::addFolder(KNFolder *f)
case 3:
type = KFolderTreeItem::SentMail; break;
}
- it = new KNCollectionViewItem( f->tqparent()->listItem(), KFolderTreeItem::Local, type );
+ it = new KNCollectionViewItem( f->parent()->listItem(), KFolderTreeItem::Local, type );
}
f->setListItem( it );
updateFolder( f );
diff --git a/knode/kncollectionviewitem.cpp b/knode/kncollectionviewitem.cpp
index 245ea777..4c1f4b7a 100644
--- a/knode/kncollectionviewitem.cpp
+++ b/knode/kncollectionviewitem.cpp
@@ -32,8 +32,8 @@
#include "knconfigmanager.h"
-KNCollectionViewItem::KNCollectionViewItem( KFolderTree *tqparent, Protocol protocol, Type type) :
- KFolderTreeItem(tqparent, TQString(), protocol, type), coll(0)
+KNCollectionViewItem::KNCollectionViewItem( KFolderTree *parent, Protocol protocol, Type type) :
+ KFolderTreeItem(parent, TQString(), protocol, type), coll(0)
{
setIcon();
}
@@ -137,7 +137,7 @@ void KNCollectionViewItem::paintCell( TQPainter * p, const TQColorGroup & cg,int
if (px)
pxWidth += px->width();
// temporary set the squeezed text and use the tqparent class to paint it
TQString curText = text( column );
if ( p->fontMetrics().width( curText ) > width - pxWidth ) {
setText( column, squeezeFolderName( curText, p->fontMetrics(), width - pxWidth ) );
@@ -137,7 +137,7 @@ void KNCollectionViewItem::paintCell( TQPainter * p, const TQColorGroup & cg,int
if (px)
pxWidth += px->width();
- // temporary set the squeezed text and use the tqparent class to paint it
+ // temporary set the squeezed text and use the parent class to paint it
TQString curText = text( column );
if ( p->fontMetrics().width( curText ) > width - pxWidth ) {
diff --git a/knode/kncomposer.h b/knode/kncomposer.h
index 83b406be..d4a4c2a8 100644
--- a/knode/kncomposer.h
+++ b/knode/kncomposer.h
@@ -255,7 +255,7 @@ class KNComposer::Editor : public KEdit {
TQ_OBJECT
public:
- Editor(KNComposer::ComposerView *_composerView, KNComposer *_composer, TQWidget *tqparent=0, char *name=0);
+ Editor(KNComposer::ComposerView *_composerView, KNComposer *_composer, TQWidget *parent=0, char *name=0);
~Editor();
TQStringList processedText();
@@ -308,7 +308,7 @@ class KNComposer::AttachmentView : public KListView {
TQ_OBJECT
public:
- AttachmentView(TQWidget *tqparent, char *name=0);
+ AttachmentView(TQWidget *parent, char *name=0);
~AttachmentView();
protected:
@@ -362,10 +362,10 @@ class KNLineEdit : public KABC::AddressLineEdit
typedef KABC::AddressLineEdit KNLineEditInherited;
public:
- KNLineEdit(KNComposer::ComposerView *_composerView, bool useCompletion, TQWidget *tqparent = 0,
+ KNLineEdit(KNComposer::ComposerView *_composerView, bool useCompletion, TQWidget *parent = 0,
const char *name = 0);
protected:
// Inherited. Always called by the tqparent when this widget is created.
virtual void loadAddresses();
void keyPressEvent(TQKeyEvent *e);
virtual TQPopupMenu *createPopupMenu();
@@ -380,7 +380,7 @@ class KNLineEditSpell : public KNLineEdit
Q_OBJECT
TQ_OBJECT
public:
- KNLineEditSpell(KNComposer::ComposerView *_composerView, bool useCompletion,TQWidget * tqparent, const char * name = 0);
+ KNLineEditSpell(KNComposer::ComposerView *_composerView, bool useCompletion,TQWidget * parent, const char * name = 0);
void highLightWord( unsigned int length, unsigned int pos );
void spellCheckDone( const TQString &s );
void spellCheckerMisspelling( const TQString &text, const TQStringList &, unsigned int pos);
@@ -362,10 +362,10 @@ class KNLineEdit : public KABC::AddressLineEdit
const char *name = 0);
protected:
- // Inherited. Always called by the tqparent when this widget is created.
+ // Inherited. Always called by the parent when this widget is created.
virtual void loadAddresses();
void keyPressEvent(TQKeyEvent *e);
diff --git a/knode/knfoldermanager.cpp b/knode/knfoldermanager.cpp
index bdac2f2b..7041f456 100644
--- a/knode/knfoldermanager.cpp
+++ b/knode/knfoldermanager.cpp
@@ -156,7 +156,7 @@ bool KNFolderManager::deleteFolder(KNFolder *f)
// find all subfolders of the folder we want to delete
for ( TQValueList<KNFolder*>::Iterator it = mFolderList.begin(); it != mFolderList.end(); ++it ) {
- p = (*it)->tqparent();
+ p = (*it)->parent();
while ( p ) {
if ( p == f ) {
if ( (*it)->lockedArticles() > 0 )
@@ -164,7 +164,7 @@ bool KNFolderManager::deleteFolder(KNFolder *f)
del.append( (*it) );
break;
}
- p = p->tqparent();
+ p = p->parent();
}
}
@@ -198,15 +198,15 @@ void KNFolderManager::emptyFolder(KNFolder *f)
bool KNFolderManager::moveFolder(KNFolder *f, KNFolder *p)
{
- if(!f || p==f->tqparent()) // nothing to be done
+ if(!f || p==f->parent()) // nothing to be done
return true;
// is "p" a child of "f" ?
- KNCollection *p2=p?p->tqparent():0;
+ KNCollection *p2=p?p->parent():0;
while(p2) {
if(p2==f)
break;
- p2=p2->tqparent();
+ p2=p2->parent();
}
if( (p2 && p2==f) || f==p || f->isStandardFolder() || f->isRootFolder()) // no way ;-)
@@ -466,7 +466,7 @@ int KNFolderManager::loadCustomFolders()
// set parents
if(cnt>0) {
for ( TQValueList<KNFolder*>::Iterator it = mFolderList.begin(); it != mFolderList.end(); ++it ) {
- if ( !(*it)->isRootFolder() ) { // the root folder has no tqparent
+ if ( !(*it)->isRootFolder() ) { // the root folder has no parent
KNFolder *par = folder( (*it)->parentId() );
if ( !par )
par = root();